(* HCoop Domtool (http://hcoop.sourceforge.net/)
 * Copyright (c) 2006, Adam Chlipala
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *)

(* MySQL user/table management *)

structure MySQL :> MYSQL = struct

val validPasswd = CharVector.all (fn ch => Char.isAlphaNum ch
					   orelse ch = #"!"
					   orelse ch = #"."
					   orelse ch = #"-"
					   orelse ch = #"_")

fun adduser {user, passwd} =
    case passwd of
	NONE => SOME "No password given"
      | SOME passwd =>
	if validPasswd passwd then
	    if Slave.shell [Config.MySQL.adduser, user, " ", passwd] then
		NONE
	    else
		SOME "Error executing CREATE USER script"
	else
	    SOME "Password contains characters besides letters, digits, and !.-_"

fun passwd {user, passwd} =
    if validPasswd passwd then
	if Slave.shell [Config.MySQL.passwd, user, " ", passwd] then
	    NONE
	else
	    SOME "Error executing SET PASSWORD script"
    else
	SOME "Password contains characters besides letters, digits, and !.-_"

fun createdb {user, dbname} =
    if Slave.shell [Config.MySQL.createdb, user, " ", dbname] then
	NONE
    else
	SOME "Error executing CREATE DATABASE script"

fun dropdb {user, dbname} =
    if Slave.shell [Config.MySQL.dropdb, user, " ", dbname] then
	NONE
    else
	SOME "Error executing DROP DATABASE script"

val _ = Dbms.register ("mysql", {getpass = SOME Client.getpass,
				 adduser = adduser,
				 passwd = passwd,
				 createdb = createdb,
				 dropdb = dropdb})

end
